@@ -24,17 +24,4 @@ class Logger(object):
             with open(self.target, 'w+') as f:
                 data = json.load(f)
                 data.append(logObject)
-                json.dump(data, f)
-
-class StepLogger(object):
-    def __init__(self, logFile):
-        self.logFile = logFile
-    
-    def append(self, logObject):
-        if os.stat(self.target).st_size == 0:
-            self.write(logObject)
-        else:
-            with open(self.target, 'w+') as f:
-                data = json.load(f)
-                data.append(logObject)
-                json.dump(data, f)
+                json.dump(data, f)
\ No newline at end of file
