@@ -5,7 +5,6 @@
 
 import os
 
-from mlpm.logger import StepLogger
 from mlpm.server import run_server
 
 
@@ -38,7 +37,4 @@ class Solver(object):
         run_server(self, port)
 
     def infer(self, data):
-        raise NotImplementedError
-
-    def train(self, data):
-        self.logger = StepLogger(os.environ('LOG_FILE'))
+        raise NotImplementedError
\ No newline at end of file
